.. _api_dsutils:

.. py:module:: pynetdicom.dsutils

Dataset Utilities (:mod:`pynetdicom.dsutils`)
==============================================

.. currentmodule:: pynetdicom.dsutils

This module provides DICOM Dataset related utilities.

Encoding and Decoding
---------------------

.. autosummary::
   :toctree: generated/

   encode
   decode

Miscellaneous
-------------

.. autosummary::
   :toctree: generated/

   pretty_dataset
   pretty_element
